==> chatbot-2.25.29-sources.jar: software/amazon/awssdk/services/chatbot/paginators/ListMicrosoftTeamsChannelConfigurationsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.chatbot.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.chatbot.ChatbotClient;
import software.amazon.awssdk.services.chatbot.internal.UserAgentUtils;
import software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest;
import software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.chatbot.ChatbotClient#listMicrosoftTeamsChannelConfigurationsPaginator(software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse} that can be
 * used to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client.listMicrosoftTeamsChannelConfigurationsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client
 *             .listMicrosoftTeamsChannelConfigurationsPaginator(request);
 *     for (software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client.listMicrosoftTeamsChannelConfigurationsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listMicrosoftTeamsChannelConfigurations(software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListMicrosoftTeamsChannelConfigurationsIterable implements
        SdkIterable<ListMicrosoftTeamsChannelConfigurationsResponse> {
    private final ChatbotClient client;

    private final ListMicrosoftTeamsChannelConfigurationsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListMicrosoftTeamsChannelConfigurationsIterable(ChatbotClient client,
            ListMicrosoftTeamsChannelConfigurationsRequest firstRequest) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.nextPageFetcher = new ListMicrosoftTeamsChannelConfigurationsResponseFetcher();
    }

    @Override
    public Iterator<ListMicrosoftTeamsChannelConfigurationsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListMicrosoftTeamsChannelConfigurationsResponseFetcher implements
            SyncPageFetcher<ListMicrosoftTeamsChannelConfigurationsResponse> {
        @Override
        public boolean hasNextPage(ListMicrosoftTeamsChannelConfigurationsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListMicrosoftTeamsChannelConfigurationsResponse nextPage(
                ListMicrosoftTeamsChannelConfigurationsResponse previousPage) {
            if (previousPage == null) {
                return client.listMicrosoftTeamsChannelConfigurations(firstRequest);
            }
            return client.listMicrosoftTeamsChannelConfigurations(firstRequest.toBuilder().nextToken(previousPage.nextToken())
                    .build());
        }
    }
}

==> chatbot-2.40.16-sources.jar: software/amazon/awssdk/services/chatbot/paginators/ListMicrosoftTeamsChannelConfigurationsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.chatbot.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.chatbot.ChatbotClient;
import software.amazon.awssdk.services.chatbot.internal.UserAgentUtils;
import software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest;
import software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse;
import software.amazon.awssdk.services.chatbot.model.TeamsChannelConfiguration;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.chatbot.ChatbotClient#listMicrosoftTeamsChannelConfigurationsPaginator(software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse} that can be
 * used to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client.listMicrosoftTeamsChannelConfigurationsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client
 *             .listMicrosoftTeamsChannelConfigurationsPaginator(request);
 *     for (software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.chatbot.paginators.ListMicrosoftTeamsChannelConfigurationsIterable responses = client.listMicrosoftTeamsChannelConfigurationsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of MaxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listMicrosoftTeamsChannelConfigurations(software.amazon.awssdk.services.chatbot.model.ListMicrosoftTeamsChannelConfigurationsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListMicrosoftTeamsChannelConfigurationsIterable implements
        SdkIterable<ListMicrosoftTeamsChannelConfigurationsResponse> {
    private final ChatbotClient client;

    private final ListMicrosoftTeamsChannelConfigurationsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListMicrosoftTeamsChannelConfigurationsIterable(ChatbotClient client,
            ListMicrosoftTeamsChannelConfigurationsRequest firstRequest) {
        this.client = client;
        this.firstRequest = UserAgentUtils.applyPaginatorUserAgent(firstRequest);
        this.nextPageFetcher = new ListMicrosoftTeamsChannelConfigurationsResponseFetcher();
    }

    @Override
    public Iterator<ListMicrosoftTeamsChannelConfigurationsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link ListMicrosoftTeamsChannelConfigurationsResponse#teamChannelConfigurations()} member. The returned iterable
     * is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<TeamsChannelConfiguration> teamChannelConfigurations() {
        Function<ListMicrosoftTeamsChannelConfigurationsResponse, Iterator<TeamsChannelConfiguration>> getIterator = response -> {
            if (response != null && response.teamChannelConfigurations() != null) {
                return response.teamChannelConfigurations().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListMicrosoftTeamsChannelConfigurationsResponse, TeamsChannelConfiguration> builder()
                .pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    private class ListMicrosoftTeamsChannelConfigurationsResponseFetcher implements
            SyncPageFetcher<ListMicrosoftTeamsChannelConfigurationsResponse> {
        @Override
        public boolean hasNextPage(ListMicrosoftTeamsChannelConfigurationsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListMicrosoftTeamsChannelConfigurationsResponse nextPage(
                ListMicrosoftTeamsChannelConfigurationsResponse previousPage) {
            if (previousPage == null) {
                return client.listMicrosoftTeamsChannelConfigurations(firstRequest);
            }
            return client.listMicrosoftTeamsChannelConfigurations(firstRequest.toBuilder().nextToken(previousPage.nextToken())
                    .build());
        }
    }
}
